<?php
/**
 * Webkul MarketingCloud Magento Connector SyncAllOrder Controller
 * @category  Webkul
 * @package   Webkul_MarketingCloudMagentoConnector
 * @author    Webkul
 * @copyright Copyright (c) 2010-2017 Webkul Software Private Limited (https://webkul.com)
 * @license   https://store.webkul.com/license.html
 */

namespace Webkul\MarketingCloudMagentoConnector\Controller\Adminhtml\Order;

use Magento\Backend\App\Action;
use Magento\Ui\Component\MassAction\Filter;
use Magento\Framework\Controller\ResultFactory;

class SyncAllOrder extends \Magento\Backend\App\Action
{
    /**
     * @var \Magento\Backend\Model\View\Result\Forward
     */
    protected $_resultForwardFactory;

    /**
     * @param \Magento\Backend\App\Action\Context $context
     * @param \Magento\Backend\Model\View\Result\ForwardFactory $resultForwardFactory
     */
    public function __construct(
        \Magento\Backend\App\Action\Context $context,
        \Webkul\MarketingCloudMagentoConnector\Helper\Connection $connection,
        \Magento\Sales\Model\Order $orderModel,
        \Magento\Backend\Model\View\Result\ForwardFactory $resultForwardFactory,
        \Magento\Framework\Message\ManagerInterface $messageManager,
        \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig
    ) {


        $this->_orderModel = $orderModel;
        $this->_connection = $connection;
        $this->_resultForwardFactory = $resultForwardFactory;
        $this->_messageManager = $messageManager;
        $this->_scopeConfig = $scopeConfig;
        parent::__construct($context);
    }

    /**
     * Forward to edit
     *
     * @return \Magento\Backend\Model\View\Result\Forward
     */
    public function execute()
    {
        $helper = $this->_connection;
        $sessionToken = $this->_session->getMarketingToken();
        $token = $this->_scopeConfig->getValue('marketingcloud/general/mc_conn_token');
        $relToken = $helper->genarateToken();
        if(isset($token) && $token != null){
            $sessionToken = $token;
        }
        if ($sessionToken != $relToken) {
            $resultRedirect = $this->resultRedirectFactory->create();
            $this->messageManager->addError(__("Licence Invalid, Kindly use correct licence key!!!"));
            return $resultRedirect->setPath('adminhtml/system_config/edit/section/marketingcloudmagentoconnector');
        }
        $exportIds = [];
        $storeId = (int) $this->getRequest()->getParam('store', 0);
        $helper = $this->_connection;

        $limit = $this->_scopeConfig->getValue('marketingcloud/batch/mc_batch_order') ?? '10';
        $collection = $this->_orderModel->getCollection()
                                        ->addAttributeToFilter('status', ['neq' => 'canceled'])
                                        ->addAttributeToSelect('entity_id')->setPageSize($limit)
                                        ->setCurPage(1);

        $exportIds = $collection->getAllIds();
        $res = $helper->getSyncAllOrder($exportIds);
        if (count($collection) == 0) {
            $this->_messageManager->addSuccess(__("No Order are exist at Magento."));
        } else {
            if (count($exportIds) == 0) {
                $this->_messageManager->addSuccess(__("All Magento Orders are exported Successfully!!"));
            }
            else{
                $this->_messageManager->addSuccess(__("All Magento Orders are exported Successfully!!"));
            }
        }

        $resultRedirect = $this->resultFactory->create(ResultFactory::TYPE_REDIRECT);
        return  $resultRedirect->setPath('sales/*/', ['store' => $storeId]);
    }
}
