<?php
/**
 * Webkul MarketingCloudMagentoConnector SalesOrderAfterObserver Observer Model
 *
 * @category  Webkul
 * @package   Webkul_MarketingCloudMagentoConnector
 * @author    Webkul
 * @copyright Copyright (c) 2010-2017 Webkul Software Private Limited (https://webkul.com)
 * @license   https://store.webkul.com/license.html
 *
 */
namespace Webkul\MarketingCloudMagentoConnector\Observer;

use Magento\Framework\Event\Manager;
use Magento\Framework\Event\ObserverInterface;
use Webkul\MarketingCloudMagentoConnector\Helper\Connection;

class SalesOrderAfterObserver implements ObserverInterface
{
    public function __construct(
        \Magento\Framework\App\RequestInterface $requestInterface,
        \Magento\Framework\Message\ManagerInterface $messageManager,
        \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig,
        \Webkul\MarketingCloudMagentoConnector\Helper\Connection $connection
    ) {
        $this->_connection = $connection;
        $this->_scopeConfig = $scopeConfig;
        $this->_messageManager = $messageManager;
        $this->_requestInterface = $requestInterface;
    }

    /**
     * Sale Order Save After event handler
     *
     * @param \Magento\Framework\Event\Observer $observer
     * @return void
     */
    public function execute(\Magento\Framework\Event\Observer $observer)
    {
        $lastOrderId = $observer->getEvent()->getData('order');
        $orderId = $lastOrderId->getId();
        $helper = $this->_connection;
        $autoOrder = $this->_scopeConfig->getValue('marketingcloud/general/mc_autosync');
        if ($lastOrderId && $autoOrder == '1') {
            if (!$lastOrderId) {
                return;
            }
            $res = $helper->getAutoSyncOrder($orderId);
            if($res && $res[0]){
                $message = "Order Successfully Exported In DataExtension!!!";
                $this->_messageManager->addSuccess(__($message));
            } else{
                $respMessage = $res[1];
                $error = "Error,  >> ".$respMessage;
                $this->_messageManager->addError(__($error));
            }
        }
    }
}
